@@ -1,6 +1,10 @@
 package Dist::Zilla::Plugin::FFI::CheckLib;
-$Dist::Zilla::Plugin::FFI::CheckLib::VERSION = '0.002001';
-use strict; use warnings;
+
+use strict;
+use warnings;
+
+# ABSTRACT: FFI::CheckLib alternative to Dist::Zilla::Plugin::CheckLib
+our $VERSION = '1.00'; # VERSION
 
 use Moose;
 with
@@ -130,10 +134,16 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::FFI::CheckLib - FFI::CheckLib alternative to Dist::Zilla::Plugin::CheckLib
 
+=head1 VERSION
+
+version 1.00
+
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
@@ -153,8 +163,6 @@ which will result in a NA result on a CPAN test reporter.
 Derived from L<Dist::Zilla::Plugin::CheckLib> (see L</AUTHOR>) -- look there
 for non-FFI applications.
 
-=for Pod::Coverage mvp_multivalue_args register_prereqs munge_files setup_installer
-
 =head1 CONFIGURATION OPTIONS
 
 All options are as documented in L<FFI::CheckLib>:
@@ -207,10 +215,13 @@ L<Devel::AssertOS> and L<Dist::Zilla::Plugin::AssertOS>
 
 =head1 AUTHOR
 
-Ported to L<FFI::CheckLib> by Jon Portnoy <avenj@cobaltirc.org>
+Original author: Jon Portnoy
 
-This module is adapted directly from L<Dist::Zilla::Plugin::CheckLib>,
-copyright (c) 2014 by Karen Etheridge (CPAN: ETHER).
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Jon Portnoy.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
